voice-typing-0.1.0 is not a library.
voice-typing
Fast local voice typing for any focused window or browser input.
Repository: https://github.com/maceip/voice-typing
Fast local voice typing for any focused window or browser input.
Repository: https://github.com/maceip/voice-typing